==> gap-openmath_11.5.0+ds.orig.tar.xz: gap-openmath-11.5.0+ds/README.md <==
[![Build Status](https://travis-ci.org/gap-packages/openmath.svg?branch=master)](https://travis-ci.org/gap-packages/openmath)
[![Code Coverage](https://codecov.io/github/gap-packages/openmath/coverage.svg?branch=master&token=)](https://codecov.io/gh/gap-packages/openmath)

# The OpenMath package

This package provides a GAP phrasebook for OpenMath (http://www.openmath.org/):
it allows GAP users to import and export mathematical objects encoded in
OpenMath, for the purpose of exchanging them with other OpenMath-enabled 
applications.

The OpenMath package is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your option) any
later version. See the FSF's own site http://www.gnu.org/licenses/gpl.html
for the details.

The installation of the package is standard: for details, see GAP reference
manual, chapter "GAP Packages" (and if you don't have write access to the
Gap installation, type in GAP "?GAP root directory" to see another relevant
part of the manual).

## Documentation

Full information and documentation can be found in the manual, available
as PDF `doc/manual.pdf` or as HTML `doc/chap0.html`, or on the package
homepage at

  <http://gap-packages.github.io/openmath/>


## Bug reports and feature requests

Please submit bug reports and feature requests via our GitHub issue tracker:

  <https://github.com/gap-packages/OpenMath/issues>


License
=======

OpenMath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

For details see the COPYING file.

==> gap-openmath_11.5.3+ds.orig.tar.xz: gap-openmath-11.5.3+ds/README.md <==
[![Build Status](https://github.com/gap-packages/openmath/workflows/CI/badge.svg?branch=master)](https://github.com/gap-packages/openmath/actions?query=workflow%3ACI+branch%3Amaster)
[![Code Coverage](https://codecov.io/github/gap-packages/openmath/coverage.svg?branch=master&token=)](https://codecov.io/gh/gap-packages/openmath)

# The OpenMath package

This package provides a GAP phrasebook for [OpenMath](https://www.openmath.org/):
it allows GAP users to import and export mathematical objects encoded in
OpenMath, for the purpose of exchanging them with other OpenMath-enabled 
applications.

The OpenMath package is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the Free
Software Foundation; either version 2 of the License, or (at your option) any
later version. See the FSF's own site <https://www.gnu.org/licenses/gpl.html>
for the details.

The installation of the package is standard: for details, see GAP reference
manual, chapter "GAP Packages" (and if you don't have write access to the
Gap installation, type in GAP "?GAP root directory" to see another relevant
part of the manual).

## Documentation

Full information and documentation can be found in the manual, available
as PDF `doc/manual.pdf` or as HTML `doc/chap0.html`, or on the package
homepage at

  <https://gap-packages.github.io/openmath/>


## Bug reports and feature requests

Please submit bug reports and feature requests via our GitHub issue tracker:

  <https://github.com/gap-packages/OpenMath/issues>


License
=======

OpenMath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2 of the License, or (at your
option) any later version.

For details see the COPYING file.
